# Generated by roxygen2: do not edit by hand

export(bar.evaluate.core)
export(box.evaluate.core)
export(chisquare.evaluate.core)
export(corr.evaluate.core)
export(coverage.evaluate.core)
export(cr.evaluate.core)
export(dist.evaluate.core)
export(diversity.evaluate.core)
export(freqdist.evaluate.core)
export(iqr.evaluate.core)
export(levene.evaluate.core)
export(pca.evaluate.core)
export(pdfdist.evaluate.core)
export(percentdiff.evaluate.core)
export(qq.evaluate.core)
export(rpr.evaluate.core)
export(scv.evaluate.core)
export(shannon.evaluate.core)
export(signtest.evaluate.core)
export(snk.evaluate.core)
export(ttest.evaluate.core)
export(vpf.evaluate.core)
export(vr.evaluate.core)
export(wilcox.evaluate.core)
import(ggcorrplot)
import(ggplot2)
import(ggtext)
import(mathjaxr)
importFrom(Rdpack,reprompt)
importFrom(agricolae,SNK.test)
importFrom(boot,boot)
importFrom(car,leveneTest)
importFrom(cluster,daisy)
importFrom(dplyr,bind_rows)
importFrom(dplyr,n)
importFrom(dplyr,summarise)
importFrom(entropy,KL.plugin)
importFrom(entropy,discretize)
importFrom(grDevices,col2rgb)
importFrom(grDevices,nclass.FD)
importFrom(grDevices,nclass.Sturges)
importFrom(grDevices,nclass.scott)
importFrom(gridExtra,grid.arrange)
importFrom(kSamples,ad.test)
importFrom(missMDA,imputePCA)
importFrom(psych,shannon)
importFrom(reshape2,melt)
importFrom(stats,IQR)
importFrom(stats,aov)
importFrom(stats,chisq.test)
importFrom(stats,cor)
importFrom(stats,dnorm)
importFrom(stats,formula)
importFrom(stats,ks.test)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,prcomp)
importFrom(stats,pt)
importFrom(stats,qqplot)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(tibble,as_tibble)
importFrom(tibble,deframe)
importFrom(vegan,mantel)
