% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iqr.evaluate.core.R
\name{iqr.evaluate.core}
\alias{iqr.evaluate.core}
\title{Interquartile Range}
\usage{
iqr.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the accession count (excluding missing  data) as
  well as the IQR values of the EC and CS for the traits specified as
  \code{quantitative}.
}
\description{
Compute the Interquartile Range (IQR)
\insertCite{upton_general_1996}{EvaluateCore} to compare quantitative traits
of the entire collection (EC) and core set (CS).
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

iqr.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[stats]{IQR}}
}
