% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/levene.evaluate.core.R
\name{levene.evaluate.core}
\alias{levene.evaluate.core}
\title{Levene's Test}
\usage{
levene.evaluate.core(data, names, quantitative, selected)
}
\arguments{
\item{data}{The data as a data frame object. The data frame should possess
one row per individual and columns with the individual names and multiple
trait/character data.}

\item{names}{Name of column with the individual names as a character string.}

\item{quantitative}{Name of columns with the quantitative traits as a
character vector.}

\item{selected}{Character vector with the names of individuals selected in
core collection and present in the \code{names} column.}
}
\value{
A data frame with the following columns \item{Trait}{The quantitative
  trait.} \item{Count}{The accession count (excluding missing data).}
  \item{Df}{The degrees of freedom for the test.} \item{EC_V}{The variance of
  the EC.} \item{CS_V}{The variance of the CS.} \item{EC_CV}{The coefficient
  of variance of the EC.} \item{CS_CV}{The coefficient of variance of the
  CS.} \item{Levene_Fvalue}{The test statistic.} \item{Levene_pvalue}{The p
  value for the test statistic.} \item{Levene_significance}{The significance
  of the test statistic (*: p \mjseqn{\leq} 0.01; **: p \mjseqn{\leq} 0.05;
  ns: p \mjseqn{ > } 0.05).}
}
\description{
Test for  of variances of the entire collection (EC) and core set (CS) for
quantitative traits by Levene's test
\insertCite{levene_robust_1960}{EvaluateCore}.
}
\examples{

data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

levene.evaluate.core(data = ec, names = "genotypes",
                     quantitative = quant, selected = core)

}
\references{
\insertAllCited{}
}
\seealso{
\code{\link[car]{leveneTest}}
}
